﻿using esoft.Class;
using esoft.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace esoft.Pages
{
    /// <summary>
    /// Логика взаимодействия для TaskLists.xaml
    /// </summary>
    public partial class TaskLists : Page
    {
        ActualContext actualContext = new ActualContext();   // Контекст таблиц
        TaskFill tasks = new TaskFill();                    // Полученный контекст формы
        List<TaskFill> taskContext = new List<TaskFill>(); // Список задач

        public TaskLists()
        {
            InitializeComponent();
            LViewTask.ItemsSource = Class.TaskFill.TaskFills();
            FillForm();
        }

        private void FillForm()
        {
            cbStatus.ItemsSource = StatusTask.FillStatus();

            List<User> usersExecutor = actualContext.Users.Where(user => actualContext.Executor.Any(ex => ex.ID == user.ID)).ToList(); // Получение списка исполнителей
            cbExecutor.ItemsSource = UserInFIO.GroupUser(usersExecutor);

            List<User> usersManager = actualContext.Users.Where(user => actualContext.Manager.Any(manager => manager.ID == user.ID)).ToList(); // Получение списка менеджеров
            cbManager.ItemsSource = UserInFIO.GroupUser(usersManager);
        }

        private void BtnAddTask_Click(object sender, RoutedEventArgs e)
        {
            TaskFill newTask = new TaskFill(); // Создаем новую пустую задачу
            AddEditServicePage editPage = new AddEditServicePage(newTask);
            NavigationService.Navigate(editPage); // Открываем окно редактирования
        }

        private void BtnDeleteTask_Click(object sender, RoutedEventArgs e)
        {
            if (LViewTask.SelectedItem is TaskFill selectedTask)
            {
                MessageBoxResult result = MessageBox.Show("Вы уверены, что хотите удалить выбранную задачу?",
                                                          "Подтверждение удаления",
                                                          MessageBoxButton.YesNo,
                                                          MessageBoxImage.Question);

                if (result == MessageBoxResult.Yes)
                {
                    var context = esoftEntities.GetContext();

                    // Находим задачу по ID или другому уникальному идентификатору
                    var taskToDelete = context.Task.FirstOrDefault(task => task.ID == selectedTask.ID);

                    if (taskToDelete != null)
                    {
                        context.Task.Remove(taskToDelete);
                        context.SaveChanges(); // Сохраняем изменения в базе данных
                        LViewTask.ItemsSource = Class.TaskFill.TaskFills(); // Обновляем DataGrid
                    }
                }
            }
        }

        private void BtnUpdate_Click(object sender, RoutedEventArgs e)
        {
            LViewTask.ItemsSource = Class.TaskFill.TaskFills();
        }

        private void FilterTasks()
        {
            // Получение актуальных данных задач из базы или контекста приложения
            taskContext = Class.TaskFill.TaskFills();

            if (cbStatus.SelectedItem != null)
            {
                string selectedStatus = ((StatusTask)cbStatus.SelectedItem).Name;
                taskContext = taskContext.Where(task => task.Status == selectedStatus).ToList();
            }

            if (cbExecutor.SelectedItem != null)
            {
                string selectedExecutor = cbExecutor.SelectedItem.ToString();
                taskContext = taskContext.Where(task => task.FioUser == selectedExecutor).ToList();
            }

            if (cbManager.SelectedItem != null)
            {
                string selectedManager = cbManager.SelectedItem.ToString();
                taskContext = taskContext.Where(task => task.FioManager == selectedManager).ToList();
            }

            if (!string.IsNullOrEmpty(Search.Text))
            {
                string searchText = Search.Text.ToLower(); // Преобразование текста поиска к нижнему регистру (для удобства сравнения)

                // Фильтрация задач по содержанию текста в полях Title
                taskContext = taskContext.Where(task => task.Title.ToLower().Contains(searchText)).ToList();
            }

            LViewTask.ItemsSource = taskContext;
        }

        private void cbStatus_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            FilterTasks();
        }

        private void cbExecutor_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            FilterTasks();
        }

        private void cbManager_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            FilterTasks();
        }

        private void Search_TextChanged(object sender, TextChangedEventArgs e)
        {
            FilterTasks();
        }

        private void btnClearFilter_Click(object sender, RoutedEventArgs e)
        {
            // Очистка выбранных значений комбо боксов
            cbStatus.SelectedItem = null;
            cbExecutor.SelectedItem = null;
            cbManager.SelectedItem = null;
            Search.Text = string.Empty;

            // Очистка фильтров и отображение всех задач без фильтрации
            LViewTask.ItemsSource = Class.TaskFill.TaskFills();
        }

        private void LViewTask_Loaded(object sender, RoutedEventArgs e)
        {
            LViewTask.ItemsSource = Class.TaskFill.TaskFills();
        }

        private void LViewTask_MouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            if (LViewTask.SelectedItem is TaskFill selectedTask)
            {
                AddEditServicePage editPage = new AddEditServicePage(selectedTask); // Передаем выбранную задачу в окно редактирования
                NavigationService.Navigate(editPage); // Открываем окно редактирования
            }
            else
            {
                MessageBox.Show("Выберите задачу для редактирования.", "Внимание", MessageBoxButton.OK, MessageBoxImage.Information);
            }
        }
    }
}
